@@ -86,20 +86,20 @@ class Meanvariance(Base):
 
 class Autocor_length(Base):
 
-    def __init__(self, nlags = 100):
+    def __init__(self, lags = 100):
         self.Data = ['magnitude']
-        self.nlags = nlags
+        self.nlags = lags
 
     def fit(self, data):
 
         magnitude = data[0]
-        AC = stattools.acf(magnitude, self.nlags)
+        AC = stattools.acf(magnitude, nlags = self.nlags)
         k = next((index for index, value in
                  enumerate(AC) if value < np.exp(-1)), None)
 
         while k is None:
-            self.nlags = self.nlags + self.nlags
-            AC = stattools.acf(magnitude, self.nlags)
+            self.nlags = self.nlags + 100
+            AC = stattools.acf(magnitude, nlags = self.nlags)
             k = next((index for index, value in
                  enumerate(AC) if value < np.exp(-1)), None)
 
